# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BucketWormArgs', 'BucketWorm']

@pulumi.input_type
class BucketWormArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[builtins.str],
                 retention_period_in_days: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a BucketWorm resource.
        :param pulumi.Input[builtins.str] bucket: The name of the bucket
        :param pulumi.Input[builtins.int] retention_period_in_days: The specified number of days to retain the Object.
        :param pulumi.Input[builtins.str] status: The status of the compliance retention policy. Optional values:
               - `InProgress`: After a compliance retention policy is created, the policy is in the InProgress status by default, and the validity period of this status is 24 hours.
               - `Locked`: The compliance retention policy is Locked.
        """
        pulumi.set(__self__, "bucket", bucket)
        if retention_period_in_days is not None:
            pulumi.set(__self__, "retention_period_in_days", retention_period_in_days)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[builtins.str]:
        """
        The name of the bucket
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="retentionPeriodInDays")
    def retention_period_in_days(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The specified number of days to retain the Object.
        """
        return pulumi.get(self, "retention_period_in_days")

    @retention_period_in_days.setter
    def retention_period_in_days(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retention_period_in_days", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the compliance retention policy. Optional values:
        - `InProgress`: After a compliance retention policy is created, the policy is in the InProgress status by default, and the validity period of this status is 24 hours.
        - `Locked`: The compliance retention policy is Locked.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _BucketWormState:
    def __init__(__self__, *,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 retention_period_in_days: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 worm_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering BucketWorm resources.
        :param pulumi.Input[builtins.str] bucket: The name of the bucket
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.int] retention_period_in_days: The specified number of days to retain the Object.
        :param pulumi.Input[builtins.str] status: The status of the compliance retention policy. Optional values:
               - `InProgress`: After a compliance retention policy is created, the policy is in the InProgress status by default, and the validity period of this status is 24 hours.
               - `Locked`: The compliance retention policy is Locked.
        :param pulumi.Input[builtins.str] worm_id: The ID of the retention policy.
        """
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if retention_period_in_days is not None:
            pulumi.set(__self__, "retention_period_in_days", retention_period_in_days)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if worm_id is not None:
            pulumi.set(__self__, "worm_id", worm_id)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the bucket
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="retentionPeriodInDays")
    def retention_period_in_days(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The specified number of days to retain the Object.
        """
        return pulumi.get(self, "retention_period_in_days")

    @retention_period_in_days.setter
    def retention_period_in_days(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retention_period_in_days", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the compliance retention policy. Optional values:
        - `InProgress`: After a compliance retention policy is created, the policy is in the InProgress status by default, and the validity period of this status is 24 hours.
        - `Locked`: The compliance retention policy is Locked.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="wormId")
    def worm_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the retention policy.
        """
        return pulumi.get(self, "worm_id")

    @worm_id.setter
    def worm_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "worm_id", value)


@pulumi.type_token("alicloud:oss/bucketWorm:BucketWorm")
class BucketWorm(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 retention_period_in_days: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        OSS Bucket Worm can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/bucketWorm:BucketWorm example <bucket>:<worm_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] bucket: The name of the bucket
        :param pulumi.Input[builtins.int] retention_period_in_days: The specified number of days to retain the Object.
        :param pulumi.Input[builtins.str] status: The status of the compliance retention policy. Optional values:
               - `InProgress`: After a compliance retention policy is created, the policy is in the InProgress status by default, and the validity period of this status is 24 hours.
               - `Locked`: The compliance retention policy is Locked.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BucketWormArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        OSS Bucket Worm can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/bucketWorm:BucketWorm example <bucket>:<worm_id>
        ```

        :param str resource_name: The name of the resource.
        :param BucketWormArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BucketWormArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 retention_period_in_days: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BucketWormArgs.__new__(BucketWormArgs)

            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            __props__.__dict__["retention_period_in_days"] = retention_period_in_days
            __props__.__dict__["status"] = status
            __props__.__dict__["create_time"] = None
            __props__.__dict__["worm_id"] = None
        super(BucketWorm, __self__).__init__(
            'alicloud:oss/bucketWorm:BucketWorm',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bucket: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            retention_period_in_days: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            worm_id: Optional[pulumi.Input[builtins.str]] = None) -> 'BucketWorm':
        """
        Get an existing BucketWorm resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] bucket: The name of the bucket
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.int] retention_period_in_days: The specified number of days to retain the Object.
        :param pulumi.Input[builtins.str] status: The status of the compliance retention policy. Optional values:
               - `InProgress`: After a compliance retention policy is created, the policy is in the InProgress status by default, and the validity period of this status is 24 hours.
               - `Locked`: The compliance retention policy is Locked.
        :param pulumi.Input[builtins.str] worm_id: The ID of the retention policy.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BucketWormState.__new__(_BucketWormState)

        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["retention_period_in_days"] = retention_period_in_days
        __props__.__dict__["status"] = status
        __props__.__dict__["worm_id"] = worm_id
        return BucketWorm(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[builtins.str]:
        """
        The name of the bucket
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="retentionPeriodInDays")
    def retention_period_in_days(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The specified number of days to retain the Object.
        """
        return pulumi.get(self, "retention_period_in_days")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the compliance retention policy. Optional values:
        - `InProgress`: After a compliance retention policy is created, the policy is in the InProgress status by default, and the validity period of this status is 24 hours.
        - `Locked`: The compliance retention policy is Locked.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="wormId")
    def worm_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the retention policy.
        """
        return pulumi.get(self, "worm_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TransitRouterCidrArgs', 'TransitRouterCidr']

@pulumi.input_type
class TransitRouterCidrArgs:
    def __init__(__self__, *,
                 cidr: pulumi.Input[builtins.str],
                 transit_router_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 publish_cidr_route: Optional[pulumi.Input[builtins.bool]] = None,
                 transit_router_cidr_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TransitRouterCidr resource.
        :param pulumi.Input[builtins.str] cidr: The new CIDR block of the transit router.
        :param pulumi.Input[builtins.str] transit_router_id: The ID of the transit router.
        :param pulumi.Input[builtins.str] description: The new description of the transit router CIDR block.
               The description must be 1 to 256 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        :param pulumi.Input[builtins.bool] publish_cidr_route: Specifies whether to allow the system to automatically add a route that points to the CIDR block to the route table of the transit router.
        :param pulumi.Input[builtins.str] transit_router_cidr_name: The new name of the transit router CIDR block.
               The name must be 1 to 128 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        """
        pulumi.set(__self__, "cidr", cidr)
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if publish_cidr_route is not None:
            pulumi.set(__self__, "publish_cidr_route", publish_cidr_route)
        if transit_router_cidr_name is not None:
            pulumi.set(__self__, "transit_router_cidr_name", transit_router_cidr_name)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Input[builtins.str]:
        """
        The new CIDR block of the transit router.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the transit router.
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new description of the transit router CIDR block.
        The description must be 1 to 256 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="publishCidrRoute")
    def publish_cidr_route(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to allow the system to automatically add a route that points to the CIDR block to the route table of the transit router.
        """
        return pulumi.get(self, "publish_cidr_route")

    @publish_cidr_route.setter
    def publish_cidr_route(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "publish_cidr_route", value)

    @property
    @pulumi.getter(name="transitRouterCidrName")
    def transit_router_cidr_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new name of the transit router CIDR block.
        The name must be 1 to 128 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        """
        return pulumi.get(self, "transit_router_cidr_name")

    @transit_router_cidr_name.setter
    def transit_router_cidr_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_cidr_name", value)


@pulumi.input_type
class _TransitRouterCidrState:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 publish_cidr_route: Optional[pulumi.Input[builtins.bool]] = None,
                 transit_router_cidr_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_cidr_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TransitRouterCidr resources.
        :param pulumi.Input[builtins.str] cidr: The new CIDR block of the transit router.
        :param pulumi.Input[builtins.str] description: The new description of the transit router CIDR block.
               The description must be 1 to 256 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        :param pulumi.Input[builtins.bool] publish_cidr_route: Specifies whether to allow the system to automatically add a route that points to the CIDR block to the route table of the transit router.
        :param pulumi.Input[builtins.str] transit_router_cidr_id: The ID of the CIDR block.
        :param pulumi.Input[builtins.str] transit_router_cidr_name: The new name of the transit router CIDR block.
               The name must be 1 to 128 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        :param pulumi.Input[builtins.str] transit_router_id: The ID of the transit router.
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if publish_cidr_route is not None:
            pulumi.set(__self__, "publish_cidr_route", publish_cidr_route)
        if transit_router_cidr_id is not None:
            pulumi.set(__self__, "transit_router_cidr_id", transit_router_cidr_id)
        if transit_router_cidr_name is not None:
            pulumi.set(__self__, "transit_router_cidr_name", transit_router_cidr_name)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new CIDR block of the transit router.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new description of the transit router CIDR block.
        The description must be 1 to 256 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="publishCidrRoute")
    def publish_cidr_route(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to allow the system to automatically add a route that points to the CIDR block to the route table of the transit router.
        """
        return pulumi.get(self, "publish_cidr_route")

    @publish_cidr_route.setter
    def publish_cidr_route(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "publish_cidr_route", value)

    @property
    @pulumi.getter(name="transitRouterCidrId")
    def transit_router_cidr_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the CIDR block.
        """
        return pulumi.get(self, "transit_router_cidr_id")

    @transit_router_cidr_id.setter
    def transit_router_cidr_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_cidr_id", value)

    @property
    @pulumi.getter(name="transitRouterCidrName")
    def transit_router_cidr_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new name of the transit router CIDR block.
        The name must be 1 to 128 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        """
        return pulumi.get(self, "transit_router_cidr_name")

    @transit_router_cidr_name.setter
    def transit_router_cidr_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_cidr_name", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the transit router.
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)


@pulumi.type_token("alicloud:cen/transitRouterCidr:TransitRouterCidr")
class TransitRouterCidr(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 publish_cidr_route: Optional[pulumi.Input[builtins.bool]] = None,
                 transit_router_cidr_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Cloud Enterprise Network (CEN) Transit Router Cidr resource.

        Used for Vpn Attachment, Connect Attachment, etc. Assign address segments.

        For information about Cloud Enterprise Network (CEN) Transit Router Cidr and how to use it, see [What is Transit Router Cidr](https://www.alibabacloud.com/help/en/cloud-enterprise-network/latest/createtransitroutercidr).

        > **NOTE:** Available since v1.193.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cen.Instance("example",
            cen_instance_name="tf_example",
            description="an example for cen")
        example_transit_router = alicloud.cen.TransitRouter("example",
            transit_router_name="tf_example",
            cen_id=example.id)
        example_transit_router_cidr = alicloud.cen.TransitRouterCidr("example",
            transit_router_id=example_transit_router.transit_router_id,
            cidr="192.168.0.0/16",
            transit_router_cidr_name="tf_example",
            description="tf_example",
            publish_cidr_route=True)
        ```

        ## Import

        Cloud Enterprise Network (CEN) Transit Router Cidr can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/transitRouterCidr:TransitRouterCidr example <transit_router_id>:<transit_router_cidr_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr: The new CIDR block of the transit router.
        :param pulumi.Input[builtins.str] description: The new description of the transit router CIDR block.
               The description must be 1 to 256 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        :param pulumi.Input[builtins.bool] publish_cidr_route: Specifies whether to allow the system to automatically add a route that points to the CIDR block to the route table of the transit router.
        :param pulumi.Input[builtins.str] transit_router_cidr_name: The new name of the transit router CIDR block.
               The name must be 1 to 128 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        :param pulumi.Input[builtins.str] transit_router_id: The ID of the transit router.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TransitRouterCidrArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Enterprise Network (CEN) Transit Router Cidr resource.

        Used for Vpn Attachment, Connect Attachment, etc. Assign address segments.

        For information about Cloud Enterprise Network (CEN) Transit Router Cidr and how to use it, see [What is Transit Router Cidr](https://www.alibabacloud.com/help/en/cloud-enterprise-network/latest/createtransitroutercidr).

        > **NOTE:** Available since v1.193.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cen.Instance("example",
            cen_instance_name="tf_example",
            description="an example for cen")
        example_transit_router = alicloud.cen.TransitRouter("example",
            transit_router_name="tf_example",
            cen_id=example.id)
        example_transit_router_cidr = alicloud.cen.TransitRouterCidr("example",
            transit_router_id=example_transit_router.transit_router_id,
            cidr="192.168.0.0/16",
            transit_router_cidr_name="tf_example",
            description="tf_example",
            publish_cidr_route=True)
        ```

        ## Import

        Cloud Enterprise Network (CEN) Transit Router Cidr can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/transitRouterCidr:TransitRouterCidr example <transit_router_id>:<transit_router_cidr_id>
        ```

        :param str resource_name: The name of the resource.
        :param TransitRouterCidrArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TransitRouterCidrArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 publish_cidr_route: Optional[pulumi.Input[builtins.bool]] = None,
                 transit_router_cidr_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TransitRouterCidrArgs.__new__(TransitRouterCidrArgs)

            if cidr is None and not opts.urn:
                raise TypeError("Missing required property 'cidr'")
            __props__.__dict__["cidr"] = cidr
            __props__.__dict__["description"] = description
            __props__.__dict__["publish_cidr_route"] = publish_cidr_route
            __props__.__dict__["transit_router_cidr_name"] = transit_router_cidr_name
            if transit_router_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_id'")
            __props__.__dict__["transit_router_id"] = transit_router_id
            __props__.__dict__["transit_router_cidr_id"] = None
        super(TransitRouterCidr, __self__).__init__(
            'alicloud:cen/transitRouterCidr:TransitRouterCidr',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            publish_cidr_route: Optional[pulumi.Input[builtins.bool]] = None,
            transit_router_cidr_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_cidr_name: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_id: Optional[pulumi.Input[builtins.str]] = None) -> 'TransitRouterCidr':
        """
        Get an existing TransitRouterCidr resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr: The new CIDR block of the transit router.
        :param pulumi.Input[builtins.str] description: The new description of the transit router CIDR block.
               The description must be 1 to 256 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        :param pulumi.Input[builtins.bool] publish_cidr_route: Specifies whether to allow the system to automatically add a route that points to the CIDR block to the route table of the transit router.
        :param pulumi.Input[builtins.str] transit_router_cidr_id: The ID of the CIDR block.
        :param pulumi.Input[builtins.str] transit_router_cidr_name: The new name of the transit router CIDR block.
               The name must be 1 to 128 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        :param pulumi.Input[builtins.str] transit_router_id: The ID of the transit router.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TransitRouterCidrState.__new__(_TransitRouterCidrState)

        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["description"] = description
        __props__.__dict__["publish_cidr_route"] = publish_cidr_route
        __props__.__dict__["transit_router_cidr_id"] = transit_router_cidr_id
        __props__.__dict__["transit_router_cidr_name"] = transit_router_cidr_name
        __props__.__dict__["transit_router_id"] = transit_router_id
        return TransitRouterCidr(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[builtins.str]:
        """
        The new CIDR block of the transit router.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The new description of the transit router CIDR block.
        The description must be 1 to 256 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="publishCidrRoute")
    def publish_cidr_route(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether to allow the system to automatically add a route that points to the CIDR block to the route table of the transit router.
        """
        return pulumi.get(self, "publish_cidr_route")

    @property
    @pulumi.getter(name="transitRouterCidrId")
    def transit_router_cidr_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the CIDR block.
        """
        return pulumi.get(self, "transit_router_cidr_id")

    @property
    @pulumi.getter(name="transitRouterCidrName")
    def transit_router_cidr_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The new name of the transit router CIDR block.
        The name must be 1 to 128 characters in length, and cannot start with http:// or https://. You can also leave this parameter empty.
        """
        return pulumi.get(self, "transit_router_cidr_name")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the transit router.
        """
        return pulumi.get(self, "transit_router_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TransitRouterPeerAttachmentArgs', 'TransitRouterPeerAttachment']

@pulumi.input_type
class TransitRouterPeerAttachmentArgs:
    def __init__(__self__, *,
                 peer_transit_router_id: pulumi.Input[builtins.str],
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_type: Optional[pulumi.Input[builtins.str]] = None,
                 cen_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 cen_id: Optional[pulumi.Input[builtins.str]] = None,
                 default_link_type: Optional[pulumi.Input[builtins.str]] = None,
                 dry_run: Optional[pulumi.Input[builtins.bool]] = None,
                 peer_transit_router_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_association_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 route_table_propagation_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transit_router_attachment_description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_peer_attachment_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TransitRouterPeerAttachment resource.
        :param pulumi.Input[builtins.str] peer_transit_router_id: The ID of the peer transit router.
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: Specifies whether to enable the local Enterprise Edition transit router to automatically advertise the routes of the inter-region connection to the peer transit router. Valid values:
        :param pulumi.Input[builtins.int] bandwidth: The bandwidth value of the inter-region connection. Unit: Mbit/s.
               
               - This parameter specifies the maximum bandwidth value for the inter-region connection if you set `BandwidthType` to `BandwidthPackage`.
               - This parameter specifies the bandwidth throttling threshold for the inter-region connection if you set `BandwidthType` to `DataTransfer`.
        :param pulumi.Input[builtins.str] bandwidth_type: The method that is used to allocate bandwidth to the inter-region connection. Valid values:
               
               - `BandwidthPackage`: allocates bandwidth from a bandwidth plan.
               - `DataTransfer`: bandwidth is billed based on the pay-by-data-transfer metering method.
        :param pulumi.Input[builtins.str] cen_bandwidth_package_id: The ID of the bandwidth plan that is used to allocate bandwidth to the inter-region connection.
               
               > **NOTE:**   If you set `BandwidthType` to `DataTransfer`, you do not need to set this parameter.
        :param pulumi.Input[builtins.str] cen_id: The ID of the Cloud Enterprise Network (CEN) instance.
        :param pulumi.Input[builtins.str] default_link_type: The default line type.
               Valid values: Platinum and Gold.
               Platinum is supported only when BandwidthType is set to DataTransfer.
        :param pulumi.Input[builtins.bool] dry_run: Whether to perform PreCheck on this request, including permissions and instance status verification. Value:
        :param pulumi.Input[builtins.str] peer_transit_router_region_id: The ID of the region where the peer transit router is deployed.
        :param pulumi.Input[builtins.str] resource_type: The resource type to attachment. Only support `VR` and default value is `VR`.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        :param pulumi.Input[builtins.bool] route_table_association_enabled: Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.
        :param pulumi.Input[builtins.bool] route_table_propagation_enabled: Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transit_router_attachment_description: The new description of the inter-region connection.
               This parameter is optional. If you enter a description, it must be 1 to 256 characters in length, and cannot start with http:// or https://.
        :param pulumi.Input[builtins.str] transit_router_attachment_name: . Field 'transit_router_attachment_name' has been deprecated from provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.
        :param pulumi.Input[builtins.str] transit_router_id: The ID of the local Enterprise Edition transit router.
        :param pulumi.Input[builtins.str] transit_router_peer_attachment_name: The new name of the inter-region connection.
               The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        pulumi.set(__self__, "peer_transit_router_id", peer_transit_router_id)
        if auto_publish_route_enabled is not None:
            pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_type is not None:
            pulumi.set(__self__, "bandwidth_type", bandwidth_type)
        if cen_bandwidth_package_id is not None:
            pulumi.set(__self__, "cen_bandwidth_package_id", cen_bandwidth_package_id)
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if default_link_type is not None:
            pulumi.set(__self__, "default_link_type", default_link_type)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if peer_transit_router_region_id is not None:
            pulumi.set(__self__, "peer_transit_router_region_id", peer_transit_router_region_id)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if route_table_association_enabled is not None:
            warnings.warn("""Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.""", DeprecationWarning)
            pulumi.log.warn("""route_table_association_enabled is deprecated: Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.""")
        if route_table_association_enabled is not None:
            pulumi.set(__self__, "route_table_association_enabled", route_table_association_enabled)
        if route_table_propagation_enabled is not None:
            warnings.warn("""Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.""", DeprecationWarning)
            pulumi.log.warn("""route_table_propagation_enabled is deprecated: Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.""")
        if route_table_propagation_enabled is not None:
            pulumi.set(__self__, "route_table_propagation_enabled", route_table_propagation_enabled)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_description is not None:
            pulumi.set(__self__, "transit_router_attachment_description", transit_router_attachment_description)
        if transit_router_attachment_name is not None:
            warnings.warn("""Field 'transit_router_attachment_name' has been deprecated since provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""transit_router_attachment_name is deprecated: Field 'transit_router_attachment_name' has been deprecated since provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.""")
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_peer_attachment_name is not None:
            pulumi.set(__self__, "transit_router_peer_attachment_name", transit_router_peer_attachment_name)

    @property
    @pulumi.getter(name="peerTransitRouterId")
    def peer_transit_router_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the peer transit router.
        """
        return pulumi.get(self, "peer_transit_router_id")

    @peer_transit_router_id.setter
    def peer_transit_router_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "peer_transit_router_id", value)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to enable the local Enterprise Edition transit router to automatically advertise the routes of the inter-region connection to the peer transit router. Valid values:
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @auto_publish_route_enabled.setter
    def auto_publish_route_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_publish_route_enabled", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The bandwidth value of the inter-region connection. Unit: Mbit/s.

        - This parameter specifies the maximum bandwidth value for the inter-region connection if you set `BandwidthType` to `BandwidthPackage`.
        - This parameter specifies the bandwidth throttling threshold for the inter-region connection if you set `BandwidthType` to `DataTransfer`.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="bandwidthType")
    def bandwidth_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The method that is used to allocate bandwidth to the inter-region connection. Valid values:

        - `BandwidthPackage`: allocates bandwidth from a bandwidth plan.
        - `DataTransfer`: bandwidth is billed based on the pay-by-data-transfer metering method.
        """
        return pulumi.get(self, "bandwidth_type")

    @bandwidth_type.setter
    def bandwidth_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_type", value)

    @property
    @pulumi.getter(name="cenBandwidthPackageId")
    def cen_bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the bandwidth plan that is used to allocate bandwidth to the inter-region connection.

        > **NOTE:**   If you set `BandwidthType` to `DataTransfer`, you do not need to set this parameter.
        """
        return pulumi.get(self, "cen_bandwidth_package_id")

    @cen_bandwidth_package_id.setter
    def cen_bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cen_bandwidth_package_id", value)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Cloud Enterprise Network (CEN) instance.
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="defaultLinkType")
    def default_link_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The default line type.
        Valid values: Platinum and Gold.
        Platinum is supported only when BandwidthType is set to DataTransfer.
        """
        return pulumi.get(self, "default_link_type")

    @default_link_type.setter
    def default_link_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_link_type", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to perform PreCheck on this request, including permissions and instance status verification. Value:
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="peerTransitRouterRegionId")
    def peer_transit_router_region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the region where the peer transit router is deployed.
        """
        return pulumi.get(self, "peer_transit_router_region_id")

    @peer_transit_router_region_id.setter
    def peer_transit_router_region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "peer_transit_router_region_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The resource type to attachment. Only support `VR` and default value is `VR`.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="routeTableAssociationEnabled")
    @_utilities.deprecated("""Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.""")
    def route_table_association_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.
        """
        return pulumi.get(self, "route_table_association_enabled")

    @route_table_association_enabled.setter
    def route_table_association_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "route_table_association_enabled", value)

    @property
    @pulumi.getter(name="routeTablePropagationEnabled")
    @_utilities.deprecated("""Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.""")
    def route_table_propagation_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.
        """
        return pulumi.get(self, "route_table_propagation_enabled")

    @route_table_propagation_enabled.setter
    def route_table_propagation_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "route_table_propagation_enabled", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentDescription")
    def transit_router_attachment_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new description of the inter-region connection.
        This parameter is optional. If you enter a description, it must be 1 to 256 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_router_attachment_description")

    @transit_router_attachment_description.setter
    def transit_router_attachment_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_description", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    @_utilities.deprecated("""Field 'transit_router_attachment_name' has been deprecated since provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.""")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        . Field 'transit_router_attachment_name' has been deprecated from provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_name", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the local Enterprise Edition transit router.
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="transitRouterPeerAttachmentName")
    def transit_router_peer_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new name of the inter-region connection.
        The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_router_peer_attachment_name")

    @transit_router_peer_attachment_name.setter
    def transit_router_peer_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_peer_attachment_name", value)


@pulumi.input_type
class _TransitRouterPeerAttachmentState:
    def __init__(__self__, *,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_type: Optional[pulumi.Input[builtins.str]] = None,
                 cen_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 cen_id: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 default_link_type: Optional[pulumi.Input[builtins.str]] = None,
                 dry_run: Optional[pulumi.Input[builtins.bool]] = None,
                 peer_transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 peer_transit_router_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_association_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 route_table_propagation_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transit_router_attachment_description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_peer_attachment_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TransitRouterPeerAttachment resources.
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: Specifies whether to enable the local Enterprise Edition transit router to automatically advertise the routes of the inter-region connection to the peer transit router. Valid values:
        :param pulumi.Input[builtins.int] bandwidth: The bandwidth value of the inter-region connection. Unit: Mbit/s.
               
               - This parameter specifies the maximum bandwidth value for the inter-region connection if you set `BandwidthType` to `BandwidthPackage`.
               - This parameter specifies the bandwidth throttling threshold for the inter-region connection if you set `BandwidthType` to `DataTransfer`.
        :param pulumi.Input[builtins.str] bandwidth_type: The method that is used to allocate bandwidth to the inter-region connection. Valid values:
               
               - `BandwidthPackage`: allocates bandwidth from a bandwidth plan.
               - `DataTransfer`: bandwidth is billed based on the pay-by-data-transfer metering method.
        :param pulumi.Input[builtins.str] cen_bandwidth_package_id: The ID of the bandwidth plan that is used to allocate bandwidth to the inter-region connection.
               
               > **NOTE:**   If you set `BandwidthType` to `DataTransfer`, you do not need to set this parameter.
        :param pulumi.Input[builtins.str] cen_id: The ID of the Cloud Enterprise Network (CEN) instance.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] default_link_type: The default line type.
               Valid values: Platinum and Gold.
               Platinum is supported only when BandwidthType is set to DataTransfer.
        :param pulumi.Input[builtins.bool] dry_run: Whether to perform PreCheck on this request, including permissions and instance status verification. Value:
        :param pulumi.Input[builtins.str] peer_transit_router_id: The ID of the peer transit router.
        :param pulumi.Input[builtins.str] peer_transit_router_region_id: The ID of the region where the peer transit router is deployed.
        :param pulumi.Input[builtins.str] region_id: The ID of the region where the local Enterprise Edition transit router is deployed.
        :param pulumi.Input[builtins.str] resource_type: The resource type to attachment. Only support `VR` and default value is `VR`.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        :param pulumi.Input[builtins.bool] route_table_association_enabled: Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.
        :param pulumi.Input[builtins.bool] route_table_propagation_enabled: Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transit_router_attachment_description: The new description of the inter-region connection.
               This parameter is optional. If you enter a description, it must be 1 to 256 characters in length, and cannot start with http:// or https://.
        :param pulumi.Input[builtins.str] transit_router_attachment_id: The ID of the inter-region connection.
        :param pulumi.Input[builtins.str] transit_router_attachment_name: . Field 'transit_router_attachment_name' has been deprecated from provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.
        :param pulumi.Input[builtins.str] transit_router_id: The ID of the local Enterprise Edition transit router.
        :param pulumi.Input[builtins.str] transit_router_peer_attachment_name: The new name of the inter-region connection.
               The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        if auto_publish_route_enabled is not None:
            pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_type is not None:
            pulumi.set(__self__, "bandwidth_type", bandwidth_type)
        if cen_bandwidth_package_id is not None:
            pulumi.set(__self__, "cen_bandwidth_package_id", cen_bandwidth_package_id)
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if default_link_type is not None:
            pulumi.set(__self__, "default_link_type", default_link_type)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if peer_transit_router_id is not None:
            pulumi.set(__self__, "peer_transit_router_id", peer_transit_router_id)
        if peer_transit_router_region_id is not None:
            pulumi.set(__self__, "peer_transit_router_region_id", peer_transit_router_region_id)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if route_table_association_enabled is not None:
            warnings.warn("""Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.""", DeprecationWarning)
            pulumi.log.warn("""route_table_association_enabled is deprecated: Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.""")
        if route_table_association_enabled is not None:
            pulumi.set(__self__, "route_table_association_enabled", route_table_association_enabled)
        if route_table_propagation_enabled is not None:
            warnings.warn("""Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.""", DeprecationWarning)
            pulumi.log.warn("""route_table_propagation_enabled is deprecated: Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.""")
        if route_table_propagation_enabled is not None:
            pulumi.set(__self__, "route_table_propagation_enabled", route_table_propagation_enabled)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_description is not None:
            pulumi.set(__self__, "transit_router_attachment_description", transit_router_attachment_description)
        if transit_router_attachment_id is not None:
            pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)
        if transit_router_attachment_name is not None:
            warnings.warn("""Field 'transit_router_attachment_name' has been deprecated since provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""transit_router_attachment_name is deprecated: Field 'transit_router_attachment_name' has been deprecated since provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.""")
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_peer_attachment_name is not None:
            pulumi.set(__self__, "transit_router_peer_attachment_name", transit_router_peer_attachment_name)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to enable the local Enterprise Edition transit router to automatically advertise the routes of the inter-region connection to the peer transit router. Valid values:
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @auto_publish_route_enabled.setter
    def auto_publish_route_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_publish_route_enabled", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The bandwidth value of the inter-region connection. Unit: Mbit/s.

        - This parameter specifies the maximum bandwidth value for the inter-region connection if you set `BandwidthType` to `BandwidthPackage`.
        - This parameter specifies the bandwidth throttling threshold for the inter-region connection if you set `BandwidthType` to `DataTransfer`.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="bandwidthType")
    def bandwidth_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The method that is used to allocate bandwidth to the inter-region connection. Valid values:

        - `BandwidthPackage`: allocates bandwidth from a bandwidth plan.
        - `DataTransfer`: bandwidth is billed based on the pay-by-data-transfer metering method.
        """
        return pulumi.get(self, "bandwidth_type")

    @bandwidth_type.setter
    def bandwidth_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_type", value)

    @property
    @pulumi.getter(name="cenBandwidthPackageId")
    def cen_bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the bandwidth plan that is used to allocate bandwidth to the inter-region connection.

        > **NOTE:**   If you set `BandwidthType` to `DataTransfer`, you do not need to set this parameter.
        """
        return pulumi.get(self, "cen_bandwidth_package_id")

    @cen_bandwidth_package_id.setter
    def cen_bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cen_bandwidth_package_id", value)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Cloud Enterprise Network (CEN) instance.
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="defaultLinkType")
    def default_link_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The default line type.
        Valid values: Platinum and Gold.
        Platinum is supported only when BandwidthType is set to DataTransfer.
        """
        return pulumi.get(self, "default_link_type")

    @default_link_type.setter
    def default_link_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_link_type", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to perform PreCheck on this request, including permissions and instance status verification. Value:
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="peerTransitRouterId")
    def peer_transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the peer transit router.
        """
        return pulumi.get(self, "peer_transit_router_id")

    @peer_transit_router_id.setter
    def peer_transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "peer_transit_router_id", value)

    @property
    @pulumi.getter(name="peerTransitRouterRegionId")
    def peer_transit_router_region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the region where the peer transit router is deployed.
        """
        return pulumi.get(self, "peer_transit_router_region_id")

    @peer_transit_router_region_id.setter
    def peer_transit_router_region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "peer_transit_router_region_id", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the region where the local Enterprise Edition transit router is deployed.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The resource type to attachment. Only support `VR` and default value is `VR`.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="routeTableAssociationEnabled")
    @_utilities.deprecated("""Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.""")
    def route_table_association_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.
        """
        return pulumi.get(self, "route_table_association_enabled")

    @route_table_association_enabled.setter
    def route_table_association_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "route_table_association_enabled", value)

    @property
    @pulumi.getter(name="routeTablePropagationEnabled")
    @_utilities.deprecated("""Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.""")
    def route_table_propagation_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.
        """
        return pulumi.get(self, "route_table_propagation_enabled")

    @route_table_propagation_enabled.setter
    def route_table_propagation_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "route_table_propagation_enabled", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentDescription")
    def transit_router_attachment_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new description of the inter-region connection.
        This parameter is optional. If you enter a description, it must be 1 to 256 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_router_attachment_description")

    @transit_router_attachment_description.setter
    def transit_router_attachment_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_description", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the inter-region connection.
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @transit_router_attachment_id.setter
    def transit_router_attachment_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_id", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    @_utilities.deprecated("""Field 'transit_router_attachment_name' has been deprecated since provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.""")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        . Field 'transit_router_attachment_name' has been deprecated from provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_name", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the local Enterprise Edition transit router.
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="transitRouterPeerAttachmentName")
    def transit_router_peer_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The new name of the inter-region connection.
        The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_router_peer_attachment_name")

    @transit_router_peer_attachment_name.setter
    def transit_router_peer_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_peer_attachment_name", value)


@pulumi.type_token("alicloud:cen/transitRouterPeerAttachment:TransitRouterPeerAttachment")
class TransitRouterPeerAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_type: Optional[pulumi.Input[builtins.str]] = None,
                 cen_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 cen_id: Optional[pulumi.Input[builtins.str]] = None,
                 default_link_type: Optional[pulumi.Input[builtins.str]] = None,
                 dry_run: Optional[pulumi.Input[builtins.bool]] = None,
                 peer_transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 peer_transit_router_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_association_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 route_table_propagation_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transit_router_attachment_description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_peer_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Cloud Enterprise Network (CEN) Transit Router Peer Attachment resource.

        For information about Cloud Enterprise Network (CEN) Transit Router Peer Attachment and how to use it, see [What is Transit Router Peer Attachment](https://next.api.alibabacloud.com/document/Cbn/2017-09-12/CreateTransitRouterPeerAttachment).

        > **NOTE:** Available since v1.128.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        region = config.get("region")
        if region is None:
            region = "cn-hangzhou"
        peer_region = config.get("peerRegion")
        if peer_region is None:
            peer_region = "cn-beijing"
        example = alicloud.cen.Instance("example",
            cen_instance_name=name,
            protection_level="REDUCED")
        example_bandwidth_package = alicloud.cen.BandwidthPackage("example",
            bandwidth=5,
            cen_bandwidth_package_name="tf_example",
            geographic_region_a_id="China",
            geographic_region_b_id="China")
        example_bandwidth_package_attachment = alicloud.cen.BandwidthPackageAttachment("example",
            instance_id=example.id,
            bandwidth_package_id=example_bandwidth_package.id)
        example_transit_router = alicloud.cen.TransitRouter("example", cen_id=example_bandwidth_package_attachment.instance_id)
        peer = alicloud.cen.TransitRouter("peer", cen_id=example_transit_router.cen_id)
        example_transit_router_peer_attachment = alicloud.cen.TransitRouterPeerAttachment("example",
            cen_id=example.id,
            transit_router_id=example_transit_router.transit_router_id,
            peer_transit_router_region_id=peer_region,
            peer_transit_router_id=peer.transit_router_id,
            cen_bandwidth_package_id=example_bandwidth_package_attachment.bandwidth_package_id,
            bandwidth=5,
            transit_router_attachment_description=name,
            transit_router_attachment_name=name)
        ```

        ## Import

        Cloud Enterprise Network (CEN) Transit Router Peer Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/transitRouterPeerAttachment:TransitRouterPeerAttachment example <cen_id>:<transit_router_attachment_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: Specifies whether to enable the local Enterprise Edition transit router to automatically advertise the routes of the inter-region connection to the peer transit router. Valid values:
        :param pulumi.Input[builtins.int] bandwidth: The bandwidth value of the inter-region connection. Unit: Mbit/s.
               
               - This parameter specifies the maximum bandwidth value for the inter-region connection if you set `BandwidthType` to `BandwidthPackage`.
               - This parameter specifies the bandwidth throttling threshold for the inter-region connection if you set `BandwidthType` to `DataTransfer`.
        :param pulumi.Input[builtins.str] bandwidth_type: The method that is used to allocate bandwidth to the inter-region connection. Valid values:
               
               - `BandwidthPackage`: allocates bandwidth from a bandwidth plan.
               - `DataTransfer`: bandwidth is billed based on the pay-by-data-transfer metering method.
        :param pulumi.Input[builtins.str] cen_bandwidth_package_id: The ID of the bandwidth plan that is used to allocate bandwidth to the inter-region connection.
               
               > **NOTE:**   If you set `BandwidthType` to `DataTransfer`, you do not need to set this parameter.
        :param pulumi.Input[builtins.str] cen_id: The ID of the Cloud Enterprise Network (CEN) instance.
        :param pulumi.Input[builtins.str] default_link_type: The default line type.
               Valid values: Platinum and Gold.
               Platinum is supported only when BandwidthType is set to DataTransfer.
        :param pulumi.Input[builtins.bool] dry_run: Whether to perform PreCheck on this request, including permissions and instance status verification. Value:
        :param pulumi.Input[builtins.str] peer_transit_router_id: The ID of the peer transit router.
        :param pulumi.Input[builtins.str] peer_transit_router_region_id: The ID of the region where the peer transit router is deployed.
        :param pulumi.Input[builtins.str] resource_type: The resource type to attachment. Only support `VR` and default value is `VR`.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        :param pulumi.Input[builtins.bool] route_table_association_enabled: Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.
        :param pulumi.Input[builtins.bool] route_table_propagation_enabled: Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transit_router_attachment_description: The new description of the inter-region connection.
               This parameter is optional. If you enter a description, it must be 1 to 256 characters in length, and cannot start with http:// or https://.
        :param pulumi.Input[builtins.str] transit_router_attachment_name: . Field 'transit_router_attachment_name' has been deprecated from provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.
        :param pulumi.Input[builtins.str] transit_router_id: The ID of the local Enterprise Edition transit router.
        :param pulumi.Input[builtins.str] transit_router_peer_attachment_name: The new name of the inter-region connection.
               The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TransitRouterPeerAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Enterprise Network (CEN) Transit Router Peer Attachment resource.

        For information about Cloud Enterprise Network (CEN) Transit Router Peer Attachment and how to use it, see [What is Transit Router Peer Attachment](https://next.api.alibabacloud.com/document/Cbn/2017-09-12/CreateTransitRouterPeerAttachment).

        > **NOTE:** Available since v1.128.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        region = config.get("region")
        if region is None:
            region = "cn-hangzhou"
        peer_region = config.get("peerRegion")
        if peer_region is None:
            peer_region = "cn-beijing"
        example = alicloud.cen.Instance("example",
            cen_instance_name=name,
            protection_level="REDUCED")
        example_bandwidth_package = alicloud.cen.BandwidthPackage("example",
            bandwidth=5,
            cen_bandwidth_package_name="tf_example",
            geographic_region_a_id="China",
            geographic_region_b_id="China")
        example_bandwidth_package_attachment = alicloud.cen.BandwidthPackageAttachment("example",
            instance_id=example.id,
            bandwidth_package_id=example_bandwidth_package.id)
        example_transit_router = alicloud.cen.TransitRouter("example", cen_id=example_bandwidth_package_attachment.instance_id)
        peer = alicloud.cen.TransitRouter("peer", cen_id=example_transit_router.cen_id)
        example_transit_router_peer_attachment = alicloud.cen.TransitRouterPeerAttachment("example",
            cen_id=example.id,
            transit_router_id=example_transit_router.transit_router_id,
            peer_transit_router_region_id=peer_region,
            peer_transit_router_id=peer.transit_router_id,
            cen_bandwidth_package_id=example_bandwidth_package_attachment.bandwidth_package_id,
            bandwidth=5,
            transit_router_attachment_description=name,
            transit_router_attachment_name=name)
        ```

        ## Import

        Cloud Enterprise Network (CEN) Transit Router Peer Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/transitRouterPeerAttachment:TransitRouterPeerAttachment example <cen_id>:<transit_router_attachment_id>
        ```

        :param str resource_name: The name of the resource.
        :param TransitRouterPeerAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TransitRouterPeerAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_type: Optional[pulumi.Input[builtins.str]] = None,
                 cen_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 cen_id: Optional[pulumi.Input[builtins.str]] = None,
                 default_link_type: Optional[pulumi.Input[builtins.str]] = None,
                 dry_run: Optional[pulumi.Input[builtins.bool]] = None,
                 peer_transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 peer_transit_router_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_association_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 route_table_propagation_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transit_router_attachment_description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_peer_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TransitRouterPeerAttachmentArgs.__new__(TransitRouterPeerAttachmentArgs)

            __props__.__dict__["auto_publish_route_enabled"] = auto_publish_route_enabled
            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["bandwidth_type"] = bandwidth_type
            __props__.__dict__["cen_bandwidth_package_id"] = cen_bandwidth_package_id
            __props__.__dict__["cen_id"] = cen_id
            __props__.__dict__["default_link_type"] = default_link_type
            __props__.__dict__["dry_run"] = dry_run
            if peer_transit_router_id is None and not opts.urn:
                raise TypeError("Missing required property 'peer_transit_router_id'")
            __props__.__dict__["peer_transit_router_id"] = peer_transit_router_id
            __props__.__dict__["peer_transit_router_region_id"] = peer_transit_router_region_id
            __props__.__dict__["resource_type"] = resource_type
            __props__.__dict__["route_table_association_enabled"] = route_table_association_enabled
            __props__.__dict__["route_table_propagation_enabled"] = route_table_propagation_enabled
            __props__.__dict__["tags"] = tags
            __props__.__dict__["transit_router_attachment_description"] = transit_router_attachment_description
            __props__.__dict__["transit_router_attachment_name"] = transit_router_attachment_name
            __props__.__dict__["transit_router_id"] = transit_router_id
            __props__.__dict__["transit_router_peer_attachment_name"] = transit_router_peer_attachment_name
            __props__.__dict__["create_time"] = None
            __props__.__dict__["region_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["transit_router_attachment_id"] = None
        super(TransitRouterPeerAttachment, __self__).__init__(
            'alicloud:cen/transitRouterPeerAttachment:TransitRouterPeerAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            bandwidth_type: Optional[pulumi.Input[builtins.str]] = None,
            cen_bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
            cen_id: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            default_link_type: Optional[pulumi.Input[builtins.str]] = None,
            dry_run: Optional[pulumi.Input[builtins.bool]] = None,
            peer_transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
            peer_transit_router_region_id: Optional[pulumi.Input[builtins.str]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_type: Optional[pulumi.Input[builtins.str]] = None,
            route_table_association_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            route_table_propagation_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            transit_router_attachment_description: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_peer_attachment_name: Optional[pulumi.Input[builtins.str]] = None) -> 'TransitRouterPeerAttachment':
        """
        Get an existing TransitRouterPeerAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: Specifies whether to enable the local Enterprise Edition transit router to automatically advertise the routes of the inter-region connection to the peer transit router. Valid values:
        :param pulumi.Input[builtins.int] bandwidth: The bandwidth value of the inter-region connection. Unit: Mbit/s.
               
               - This parameter specifies the maximum bandwidth value for the inter-region connection if you set `BandwidthType` to `BandwidthPackage`.
               - This parameter specifies the bandwidth throttling threshold for the inter-region connection if you set `BandwidthType` to `DataTransfer`.
        :param pulumi.Input[builtins.str] bandwidth_type: The method that is used to allocate bandwidth to the inter-region connection. Valid values:
               
               - `BandwidthPackage`: allocates bandwidth from a bandwidth plan.
               - `DataTransfer`: bandwidth is billed based on the pay-by-data-transfer metering method.
        :param pulumi.Input[builtins.str] cen_bandwidth_package_id: The ID of the bandwidth plan that is used to allocate bandwidth to the inter-region connection.
               
               > **NOTE:**   If you set `BandwidthType` to `DataTransfer`, you do not need to set this parameter.
        :param pulumi.Input[builtins.str] cen_id: The ID of the Cloud Enterprise Network (CEN) instance.
        :param pulumi.Input[builtins.str] create_time: The creation time of the resource
        :param pulumi.Input[builtins.str] default_link_type: The default line type.
               Valid values: Platinum and Gold.
               Platinum is supported only when BandwidthType is set to DataTransfer.
        :param pulumi.Input[builtins.bool] dry_run: Whether to perform PreCheck on this request, including permissions and instance status verification. Value:
        :param pulumi.Input[builtins.str] peer_transit_router_id: The ID of the peer transit router.
        :param pulumi.Input[builtins.str] peer_transit_router_region_id: The ID of the region where the peer transit router is deployed.
        :param pulumi.Input[builtins.str] region_id: The ID of the region where the local Enterprise Edition transit router is deployed.
        :param pulumi.Input[builtins.str] resource_type: The resource type to attachment. Only support `VR` and default value is `VR`.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        :param pulumi.Input[builtins.bool] route_table_association_enabled: Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.
        :param pulumi.Input[builtins.bool] route_table_propagation_enabled: Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transit_router_attachment_description: The new description of the inter-region connection.
               This parameter is optional. If you enter a description, it must be 1 to 256 characters in length, and cannot start with http:// or https://.
        :param pulumi.Input[builtins.str] transit_router_attachment_id: The ID of the inter-region connection.
        :param pulumi.Input[builtins.str] transit_router_attachment_name: . Field 'transit_router_attachment_name' has been deprecated from provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.
        :param pulumi.Input[builtins.str] transit_router_id: The ID of the local Enterprise Edition transit router.
        :param pulumi.Input[builtins.str] transit_router_peer_attachment_name: The new name of the inter-region connection.
               The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TransitRouterPeerAttachmentState.__new__(_TransitRouterPeerAttachmentState)

        __props__.__dict__["auto_publish_route_enabled"] = auto_publish_route_enabled
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["bandwidth_type"] = bandwidth_type
        __props__.__dict__["cen_bandwidth_package_id"] = cen_bandwidth_package_id
        __props__.__dict__["cen_id"] = cen_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["default_link_type"] = default_link_type
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["peer_transit_router_id"] = peer_transit_router_id
        __props__.__dict__["peer_transit_router_region_id"] = peer_transit_router_region_id
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["route_table_association_enabled"] = route_table_association_enabled
        __props__.__dict__["route_table_propagation_enabled"] = route_table_propagation_enabled
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["transit_router_attachment_description"] = transit_router_attachment_description
        __props__.__dict__["transit_router_attachment_id"] = transit_router_attachment_id
        __props__.__dict__["transit_router_attachment_name"] = transit_router_attachment_name
        __props__.__dict__["transit_router_id"] = transit_router_id
        __props__.__dict__["transit_router_peer_attachment_name"] = transit_router_peer_attachment_name
        return TransitRouterPeerAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether to enable the local Enterprise Edition transit router to automatically advertise the routes of the inter-region connection to the peer transit router. Valid values:
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The bandwidth value of the inter-region connection. Unit: Mbit/s.

        - This parameter specifies the maximum bandwidth value for the inter-region connection if you set `BandwidthType` to `BandwidthPackage`.
        - This parameter specifies the bandwidth throttling threshold for the inter-region connection if you set `BandwidthType` to `DataTransfer`.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="bandwidthType")
    def bandwidth_type(self) -> pulumi.Output[builtins.str]:
        """
        The method that is used to allocate bandwidth to the inter-region connection. Valid values:

        - `BandwidthPackage`: allocates bandwidth from a bandwidth plan.
        - `DataTransfer`: bandwidth is billed based on the pay-by-data-transfer metering method.
        """
        return pulumi.get(self, "bandwidth_type")

    @property
    @pulumi.getter(name="cenBandwidthPackageId")
    def cen_bandwidth_package_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the bandwidth plan that is used to allocate bandwidth to the inter-region connection.

        > **NOTE:**   If you set `BandwidthType` to `DataTransfer`, you do not need to set this parameter.
        """
        return pulumi.get(self, "cen_bandwidth_package_id")

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the Cloud Enterprise Network (CEN) instance.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="defaultLinkType")
    def default_link_type(self) -> pulumi.Output[builtins.str]:
        """
        The default line type.
        Valid values: Platinum and Gold.
        Platinum is supported only when BandwidthType is set to DataTransfer.
        """
        return pulumi.get(self, "default_link_type")

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to perform PreCheck on this request, including permissions and instance status verification. Value:
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="peerTransitRouterId")
    def peer_transit_router_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the peer transit router.
        """
        return pulumi.get(self, "peer_transit_router_id")

    @property
    @pulumi.getter(name="peerTransitRouterRegionId")
    def peer_transit_router_region_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the region where the peer transit router is deployed.
        """
        return pulumi.get(self, "peer_transit_router_region_id")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the region where the local Enterprise Edition transit router is deployed.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The resource type to attachment. Only support `VR` and default value is `VR`.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="routeTableAssociationEnabled")
    @_utilities.deprecated("""Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.""")
    def route_table_association_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Field `route_table_association_enabled` has been deprecated from provider version 1.230.0.
        """
        return pulumi.get(self, "route_table_association_enabled")

    @property
    @pulumi.getter(name="routeTablePropagationEnabled")
    @_utilities.deprecated("""Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.""")
    def route_table_propagation_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Field `route_table_propagation_enabled` has been deprecated from provider version 1.230.0.
        """
        return pulumi.get(self, "route_table_propagation_enabled")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterAttachmentDescription")
    def transit_router_attachment_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The new description of the inter-region connection.
        This parameter is optional. If you enter a description, it must be 1 to 256 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_router_attachment_description")

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the inter-region connection.
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    @_utilities.deprecated("""Field 'transit_router_attachment_name' has been deprecated since provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.""")
    def transit_router_attachment_name(self) -> pulumi.Output[builtins.str]:
        """
        . Field 'transit_router_attachment_name' has been deprecated from provider version 1.247.0. New field 'transit_router_peer_attachment_name' instead.
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the local Enterprise Edition transit router.
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterPeerAttachmentName")
    def transit_router_peer_attachment_name(self) -> pulumi.Output[builtins.str]:
        """
        The new name of the inter-region connection.
        The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_router_peer_attachment_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AuditCallbackArgs', 'AuditCallback']

@pulumi.input_type
class AuditCallbackArgs:
    def __init__(__self__, *,
                 audit_callback_name: pulumi.Input[builtins.str],
                 callback_suggestions: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 callback_types: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 crypt_type: pulumi.Input[builtins.str],
                 url: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a AuditCallback resource.
        :param pulumi.Input[builtins.str] audit_callback_name: The AuditCallback name defined by the customer. It can contain no more than 20 characters in Chinese, English, underscore (_), and digits.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_suggestions: List of audit results supported by message notification. Value: block: confirmed violation, review: Suspected violation, review: normal.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_types: A list of Callback types. Value: machineScan: Machine audit result notification, selfAudit: self-service audit notification.
        :param pulumi.Input[builtins.str] crypt_type: The encryption algorithm is used to verify that the callback request is sent by the content security service to your business service. The value is SHA256:SHA256 encryption algorithm and SM3: SM3 encryption algorithm.
        :param pulumi.Input[builtins.str] url: The detection result will be called back to the url.
        """
        pulumi.set(__self__, "audit_callback_name", audit_callback_name)
        pulumi.set(__self__, "callback_suggestions", callback_suggestions)
        pulumi.set(__self__, "callback_types", callback_types)
        pulumi.set(__self__, "crypt_type", crypt_type)
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="auditCallbackName")
    def audit_callback_name(self) -> pulumi.Input[builtins.str]:
        """
        The AuditCallback name defined by the customer. It can contain no more than 20 characters in Chinese, English, underscore (_), and digits.
        """
        return pulumi.get(self, "audit_callback_name")

    @audit_callback_name.setter
    def audit_callback_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "audit_callback_name", value)

    @property
    @pulumi.getter(name="callbackSuggestions")
    def callback_suggestions(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        List of audit results supported by message notification. Value: block: confirmed violation, review: Suspected violation, review: normal.
        """
        return pulumi.get(self, "callback_suggestions")

    @callback_suggestions.setter
    def callback_suggestions(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "callback_suggestions", value)

    @property
    @pulumi.getter(name="callbackTypes")
    def callback_types(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        A list of Callback types. Value: machineScan: Machine audit result notification, selfAudit: self-service audit notification.
        """
        return pulumi.get(self, "callback_types")

    @callback_types.setter
    def callback_types(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "callback_types", value)

    @property
    @pulumi.getter(name="cryptType")
    def crypt_type(self) -> pulumi.Input[builtins.str]:
        """
        The encryption algorithm is used to verify that the callback request is sent by the content security service to your business service. The value is SHA256:SHA256 encryption algorithm and SM3: SM3 encryption algorithm.
        """
        return pulumi.get(self, "crypt_type")

    @crypt_type.setter
    def crypt_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "crypt_type", value)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[builtins.str]:
        """
        The detection result will be called back to the url.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "url", value)


@pulumi.input_type
class _AuditCallbackState:
    def __init__(__self__, *,
                 audit_callback_name: Optional[pulumi.Input[builtins.str]] = None,
                 callback_suggestions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 callback_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 crypt_type: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AuditCallback resources.
        :param pulumi.Input[builtins.str] audit_callback_name: The AuditCallback name defined by the customer. It can contain no more than 20 characters in Chinese, English, underscore (_), and digits.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_suggestions: List of audit results supported by message notification. Value: block: confirmed violation, review: Suspected violation, review: normal.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_types: A list of Callback types. Value: machineScan: Machine audit result notification, selfAudit: self-service audit notification.
        :param pulumi.Input[builtins.str] crypt_type: The encryption algorithm is used to verify that the callback request is sent by the content security service to your business service. The value is SHA256:SHA256 encryption algorithm and SM3: SM3 encryption algorithm.
        :param pulumi.Input[builtins.str] url: The detection result will be called back to the url.
        """
        if audit_callback_name is not None:
            pulumi.set(__self__, "audit_callback_name", audit_callback_name)
        if callback_suggestions is not None:
            pulumi.set(__self__, "callback_suggestions", callback_suggestions)
        if callback_types is not None:
            pulumi.set(__self__, "callback_types", callback_types)
        if crypt_type is not None:
            pulumi.set(__self__, "crypt_type", crypt_type)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="auditCallbackName")
    def audit_callback_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The AuditCallback name defined by the customer. It can contain no more than 20 characters in Chinese, English, underscore (_), and digits.
        """
        return pulumi.get(self, "audit_callback_name")

    @audit_callback_name.setter
    def audit_callback_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "audit_callback_name", value)

    @property
    @pulumi.getter(name="callbackSuggestions")
    def callback_suggestions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of audit results supported by message notification. Value: block: confirmed violation, review: Suspected violation, review: normal.
        """
        return pulumi.get(self, "callback_suggestions")

    @callback_suggestions.setter
    def callback_suggestions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "callback_suggestions", value)

    @property
    @pulumi.getter(name="callbackTypes")
    def callback_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of Callback types. Value: machineScan: Machine audit result notification, selfAudit: self-service audit notification.
        """
        return pulumi.get(self, "callback_types")

    @callback_types.setter
    def callback_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "callback_types", value)

    @property
    @pulumi.getter(name="cryptType")
    def crypt_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The encryption algorithm is used to verify that the callback request is sent by the content security service to your business service. The value is SHA256:SHA256 encryption algorithm and SM3: SM3 encryption algorithm.
        """
        return pulumi.get(self, "crypt_type")

    @crypt_type.setter
    def crypt_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "crypt_type", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The detection result will be called back to the url.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("alicloud:aligreen/auditCallback:AuditCallback")
class AuditCallback(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 audit_callback_name: Optional[pulumi.Input[builtins.str]] = None,
                 callback_suggestions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 callback_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 crypt_type: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Aligreen Audit Callback resource.

        Callback notification after detection is completed.

        For information about Aligreen Audit Callback and how to use it, see [What is Audit Callback](https://next.api.alibabacloud.com/document/Green/2017-08-23/CreateAuditCallback).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = alicloud.aligreen.AuditCallback("default",
            crypt_type="SM3",
            audit_callback_name=name,
            url="https://www.aliyun.com/",
            callback_types=[
                "aliyunAudit",
                "selfAduit",
                "example",
            ],
            callback_suggestions=[
                "block",
                "review",
                "pass",
            ])
        ```

        ## Import

        Aligreen Audit Callback can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:aligreen/auditCallback:AuditCallback example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] audit_callback_name: The AuditCallback name defined by the customer. It can contain no more than 20 characters in Chinese, English, underscore (_), and digits.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_suggestions: List of audit results supported by message notification. Value: block: confirmed violation, review: Suspected violation, review: normal.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_types: A list of Callback types. Value: machineScan: Machine audit result notification, selfAudit: self-service audit notification.
        :param pulumi.Input[builtins.str] crypt_type: The encryption algorithm is used to verify that the callback request is sent by the content security service to your business service. The value is SHA256:SHA256 encryption algorithm and SM3: SM3 encryption algorithm.
        :param pulumi.Input[builtins.str] url: The detection result will be called back to the url.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AuditCallbackArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Aligreen Audit Callback resource.

        Callback notification after detection is completed.

        For information about Aligreen Audit Callback and how to use it, see [What is Audit Callback](https://next.api.alibabacloud.com/document/Green/2017-08-23/CreateAuditCallback).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = alicloud.aligreen.AuditCallback("default",
            crypt_type="SM3",
            audit_callback_name=name,
            url="https://www.aliyun.com/",
            callback_types=[
                "aliyunAudit",
                "selfAduit",
                "example",
            ],
            callback_suggestions=[
                "block",
                "review",
                "pass",
            ])
        ```

        ## Import

        Aligreen Audit Callback can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:aligreen/auditCallback:AuditCallback example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AuditCallbackArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuditCallbackArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 audit_callback_name: Optional[pulumi.Input[builtins.str]] = None,
                 callback_suggestions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 callback_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 crypt_type: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuditCallbackArgs.__new__(AuditCallbackArgs)

            if audit_callback_name is None and not opts.urn:
                raise TypeError("Missing required property 'audit_callback_name'")
            __props__.__dict__["audit_callback_name"] = audit_callback_name
            if callback_suggestions is None and not opts.urn:
                raise TypeError("Missing required property 'callback_suggestions'")
            __props__.__dict__["callback_suggestions"] = callback_suggestions
            if callback_types is None and not opts.urn:
                raise TypeError("Missing required property 'callback_types'")
            __props__.__dict__["callback_types"] = callback_types
            if crypt_type is None and not opts.urn:
                raise TypeError("Missing required property 'crypt_type'")
            __props__.__dict__["crypt_type"] = crypt_type
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
        super(AuditCallback, __self__).__init__(
            'alicloud:aligreen/auditCallback:AuditCallback',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            audit_callback_name: Optional[pulumi.Input[builtins.str]] = None,
            callback_suggestions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            callback_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            crypt_type: Optional[pulumi.Input[builtins.str]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None) -> 'AuditCallback':
        """
        Get an existing AuditCallback resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] audit_callback_name: The AuditCallback name defined by the customer. It can contain no more than 20 characters in Chinese, English, underscore (_), and digits.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_suggestions: List of audit results supported by message notification. Value: block: confirmed violation, review: Suspected violation, review: normal.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] callback_types: A list of Callback types. Value: machineScan: Machine audit result notification, selfAudit: self-service audit notification.
        :param pulumi.Input[builtins.str] crypt_type: The encryption algorithm is used to verify that the callback request is sent by the content security service to your business service. The value is SHA256:SHA256 encryption algorithm and SM3: SM3 encryption algorithm.
        :param pulumi.Input[builtins.str] url: The detection result will be called back to the url.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuditCallbackState.__new__(_AuditCallbackState)

        __props__.__dict__["audit_callback_name"] = audit_callback_name
        __props__.__dict__["callback_suggestions"] = callback_suggestions
        __props__.__dict__["callback_types"] = callback_types
        __props__.__dict__["crypt_type"] = crypt_type
        __props__.__dict__["url"] = url
        return AuditCallback(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="auditCallbackName")
    def audit_callback_name(self) -> pulumi.Output[builtins.str]:
        """
        The AuditCallback name defined by the customer. It can contain no more than 20 characters in Chinese, English, underscore (_), and digits.
        """
        return pulumi.get(self, "audit_callback_name")

    @property
    @pulumi.getter(name="callbackSuggestions")
    def callback_suggestions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of audit results supported by message notification. Value: block: confirmed violation, review: Suspected violation, review: normal.
        """
        return pulumi.get(self, "callback_suggestions")

    @property
    @pulumi.getter(name="callbackTypes")
    def callback_types(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        A list of Callback types. Value: machineScan: Machine audit result notification, selfAudit: self-service audit notification.
        """
        return pulumi.get(self, "callback_types")

    @property
    @pulumi.getter(name="cryptType")
    def crypt_type(self) -> pulumi.Output[builtins.str]:
        """
        The encryption algorithm is used to verify that the callback request is sent by the content security service to your business service. The value is SHA256:SHA256 encryption algorithm and SM3: SM3 encryption algorithm.
        """
        return pulumi.get(self, "crypt_type")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        The detection result will be called back to the url.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 base_path: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_log_config: Optional[pulumi.Input['GroupUserLogConfigArgs']] = None,
                 vpc_intranet_enable: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[builtins.str] base_path: The base path of the api gateway group. Defaults to `/`.
        :param pulumi.Input[builtins.str] description: The description of the api gateway group. Defaults to null.
        :param pulumi.Input[builtins.str] instance_id: The id of the api gateway.
        :param pulumi.Input[builtins.str] name: The name of the api gateway group. Defaults to null.
        :param pulumi.Input['GroupUserLogConfigArgs'] user_log_config: user_log_config defines the config of user log of the group. See `user_log_config` below.
        :param pulumi.Input[builtins.bool] vpc_intranet_enable: Whether to enable `vpc_domain`. Defaults to `false`.
        """
        if base_path is not None:
            pulumi.set(__self__, "base_path", base_path)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if user_log_config is not None:
            pulumi.set(__self__, "user_log_config", user_log_config)
        if vpc_intranet_enable is not None:
            pulumi.set(__self__, "vpc_intranet_enable", vpc_intranet_enable)

    @property
    @pulumi.getter(name="basePath")
    def base_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The base path of the api gateway group. Defaults to `/`.
        """
        return pulumi.get(self, "base_path")

    @base_path.setter
    def base_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "base_path", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the api gateway group. Defaults to null.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the api gateway.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the api gateway group. Defaults to null.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="userLogConfig")
    def user_log_config(self) -> Optional[pulumi.Input['GroupUserLogConfigArgs']]:
        """
        user_log_config defines the config of user log of the group. See `user_log_config` below.
        """
        return pulumi.get(self, "user_log_config")

    @user_log_config.setter
    def user_log_config(self, value: Optional[pulumi.Input['GroupUserLogConfigArgs']]):
        pulumi.set(self, "user_log_config", value)

    @property
    @pulumi.getter(name="vpcIntranetEnable")
    def vpc_intranet_enable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable `vpc_domain`. Defaults to `false`.
        """
        return pulumi.get(self, "vpc_intranet_enable")

    @vpc_intranet_enable.setter
    def vpc_intranet_enable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "vpc_intranet_enable", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 base_path: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 sub_domain: Optional[pulumi.Input[builtins.str]] = None,
                 user_log_config: Optional[pulumi.Input['GroupUserLogConfigArgs']] = None,
                 vpc_domain: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_intranet_enable: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[builtins.str] base_path: The base path of the api gateway group. Defaults to `/`.
        :param pulumi.Input[builtins.str] description: The description of the api gateway group. Defaults to null.
        :param pulumi.Input[builtins.str] instance_id: The id of the api gateway.
        :param pulumi.Input[builtins.str] name: The name of the api gateway group. Defaults to null.
        :param pulumi.Input[builtins.str] sub_domain: (Available in 1.69.0+)	Second-level domain name automatically assigned to the API group.
        :param pulumi.Input['GroupUserLogConfigArgs'] user_log_config: user_log_config defines the config of user log of the group. See `user_log_config` below.
        :param pulumi.Input[builtins.str] vpc_domain: (Available in 1.69.0+)	Second-level VPC domain name automatically assigned to the API group.
        :param pulumi.Input[builtins.bool] vpc_intranet_enable: Whether to enable `vpc_domain`. Defaults to `false`.
        """
        if base_path is not None:
            pulumi.set(__self__, "base_path", base_path)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if sub_domain is not None:
            pulumi.set(__self__, "sub_domain", sub_domain)
        if user_log_config is not None:
            pulumi.set(__self__, "user_log_config", user_log_config)
        if vpc_domain is not None:
            pulumi.set(__self__, "vpc_domain", vpc_domain)
        if vpc_intranet_enable is not None:
            pulumi.set(__self__, "vpc_intranet_enable", vpc_intranet_enable)

    @property
    @pulumi.getter(name="basePath")
    def base_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The base path of the api gateway group. Defaults to `/`.
        """
        return pulumi.get(self, "base_path")

    @base_path.setter
    def base_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "base_path", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the api gateway group. Defaults to null.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the api gateway.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the api gateway group. Defaults to null.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="subDomain")
    def sub_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Available in 1.69.0+)	Second-level domain name automatically assigned to the API group.
        """
        return pulumi.get(self, "sub_domain")

    @sub_domain.setter
    def sub_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sub_domain", value)

    @property
    @pulumi.getter(name="userLogConfig")
    def user_log_config(self) -> Optional[pulumi.Input['GroupUserLogConfigArgs']]:
        """
        user_log_config defines the config of user log of the group. See `user_log_config` below.
        """
        return pulumi.get(self, "user_log_config")

    @user_log_config.setter
    def user_log_config(self, value: Optional[pulumi.Input['GroupUserLogConfigArgs']]):
        pulumi.set(self, "user_log_config", value)

    @property
    @pulumi.getter(name="vpcDomain")
    def vpc_domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Available in 1.69.0+)	Second-level VPC domain name automatically assigned to the API group.
        """
        return pulumi.get(self, "vpc_domain")

    @vpc_domain.setter
    def vpc_domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_domain", value)

    @property
    @pulumi.getter(name="vpcIntranetEnable")
    def vpc_intranet_enable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to enable `vpc_domain`. Defaults to `false`.
        """
        return pulumi.get(self, "vpc_intranet_enable")

    @vpc_intranet_enable.setter
    def vpc_intranet_enable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "vpc_intranet_enable", value)


@pulumi.type_token("alicloud:apigateway/group:Group")
class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 base_path: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_log_config: Optional[pulumi.Input[Union['GroupUserLogConfigArgs', 'GroupUserLogConfigArgsDict']]] = None,
                 vpc_intranet_enable: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.apigateway.Group("default",
            name="tf_example",
            description="tf_example",
            base_path="/",
            user_log_config={
                "request_body": True,
                "response_body": True,
                "query_string": "*",
                "request_headers": "*",
                "response_headers": "*",
                "jwt_claims": "*",
            })
        ```

        ## Import

        Api gateway group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apigateway/group:Group example "ab2351f2ce904edaa8d92a0510832b91"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] base_path: The base path of the api gateway group. Defaults to `/`.
        :param pulumi.Input[builtins.str] description: The description of the api gateway group. Defaults to null.
        :param pulumi.Input[builtins.str] instance_id: The id of the api gateway.
        :param pulumi.Input[builtins.str] name: The name of the api gateway group. Defaults to null.
        :param pulumi.Input[Union['GroupUserLogConfigArgs', 'GroupUserLogConfigArgsDict']] user_log_config: user_log_config defines the config of user log of the group. See `user_log_config` below.
        :param pulumi.Input[builtins.bool] vpc_intranet_enable: Whether to enable `vpc_domain`. Defaults to `false`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[GroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.apigateway.Group("default",
            name="tf_example",
            description="tf_example",
            base_path="/",
            user_log_config={
                "request_body": True,
                "response_body": True,
                "query_string": "*",
                "request_headers": "*",
                "response_headers": "*",
                "jwt_claims": "*",
            })
        ```

        ## Import

        Api gateway group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apigateway/group:Group example "ab2351f2ce904edaa8d92a0510832b91"
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 base_path: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 user_log_config: Optional[pulumi.Input[Union['GroupUserLogConfigArgs', 'GroupUserLogConfigArgsDict']]] = None,
                 vpc_intranet_enable: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["base_path"] = base_path
            __props__.__dict__["description"] = description
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["name"] = name
            __props__.__dict__["user_log_config"] = user_log_config
            __props__.__dict__["vpc_intranet_enable"] = vpc_intranet_enable
            __props__.__dict__["sub_domain"] = None
            __props__.__dict__["vpc_domain"] = None
        super(Group, __self__).__init__(
            'alicloud:apigateway/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            base_path: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            sub_domain: Optional[pulumi.Input[builtins.str]] = None,
            user_log_config: Optional[pulumi.Input[Union['GroupUserLogConfigArgs', 'GroupUserLogConfigArgsDict']]] = None,
            vpc_domain: Optional[pulumi.Input[builtins.str]] = None,
            vpc_intranet_enable: Optional[pulumi.Input[builtins.bool]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] base_path: The base path of the api gateway group. Defaults to `/`.
        :param pulumi.Input[builtins.str] description: The description of the api gateway group. Defaults to null.
        :param pulumi.Input[builtins.str] instance_id: The id of the api gateway.
        :param pulumi.Input[builtins.str] name: The name of the api gateway group. Defaults to null.
        :param pulumi.Input[builtins.str] sub_domain: (Available in 1.69.0+)	Second-level domain name automatically assigned to the API group.
        :param pulumi.Input[Union['GroupUserLogConfigArgs', 'GroupUserLogConfigArgsDict']] user_log_config: user_log_config defines the config of user log of the group. See `user_log_config` below.
        :param pulumi.Input[builtins.str] vpc_domain: (Available in 1.69.0+)	Second-level VPC domain name automatically assigned to the API group.
        :param pulumi.Input[builtins.bool] vpc_intranet_enable: Whether to enable `vpc_domain`. Defaults to `false`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["base_path"] = base_path
        __props__.__dict__["description"] = description
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["name"] = name
        __props__.__dict__["sub_domain"] = sub_domain
        __props__.__dict__["user_log_config"] = user_log_config
        __props__.__dict__["vpc_domain"] = vpc_domain
        __props__.__dict__["vpc_intranet_enable"] = vpc_intranet_enable
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="basePath")
    def base_path(self) -> pulumi.Output[builtins.str]:
        """
        The base path of the api gateway group. Defaults to `/`.
        """
        return pulumi.get(self, "base_path")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the api gateway group. Defaults to null.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the api gateway.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the api gateway group. Defaults to null.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="subDomain")
    def sub_domain(self) -> pulumi.Output[builtins.str]:
        """
        (Available in 1.69.0+)	Second-level domain name automatically assigned to the API group.
        """
        return pulumi.get(self, "sub_domain")

    @property
    @pulumi.getter(name="userLogConfig")
    def user_log_config(self) -> pulumi.Output[Optional['outputs.GroupUserLogConfig']]:
        """
        user_log_config defines the config of user log of the group. See `user_log_config` below.
        """
        return pulumi.get(self, "user_log_config")

    @property
    @pulumi.getter(name="vpcDomain")
    def vpc_domain(self) -> pulumi.Output[builtins.str]:
        """
        (Available in 1.69.0+)	Second-level VPC domain name automatically assigned to the API group.
        """
        return pulumi.get(self, "vpc_domain")

    @property
    @pulumi.getter(name="vpcIntranetEnable")
    def vpc_intranet_enable(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to enable `vpc_domain`. Defaults to `false`.
        """
        return pulumi.get(self, "vpc_intranet_enable")

